@@ -251,8 +251,8 @@ class DeltaTable:
         create_table_query_str += " )"
         upsert_sql_str += f"{merge_update_set_str} WHEN NOT MATCHED THEN INSERT ({merge_insert_str}) VALUES ({merge_insert_values_str})"
 
-        print(f"create_table_query_str: {create_table_query_str}")
-        print(f"upsert_sql_str: {upsert_sql_str}")
+        # print(f"create_table_query_str: {create_table_query_str}")
+        # print(f"upsert_sql_str: {upsert_sql_str}")
 
         return {
             'struct_field_list': struct_field_list,
@@ -318,6 +318,8 @@ class DeltaTable:
         log_msg.add('upload_path', self.upload_path)
         log_msg.add('checkpoint_path', self.checkpoint_path)
         log_msg.add('write_path', self.write_path)
+        log_msg.add('create_table_query_str', self.create_table_query_str)
+        log_msg.add('upsert_sql_str', self.upsert_sql_str)
         print(str(log_msg))
         logger.info(str(log_msg))
         log_msg.clear()
